//*********************************************************
//
// Copyright (c) Microsoft. All rights reserved.
// This code is licensed under the MIT License (MIT).
// THIS CODE IS PROVIDED *AS IS* WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING ANY
// IMPLIED WARRANTIES OF FITNESS FOR A PARTICULAR
// PURPOSE, MERCHANTABILITY, OR NON-INFRINGEMENT.
//
//*********************************************************

struct PSInput
{
    float4 position : SV_POSITION;
    uint color : COLOR;
    float2 uv : TEXCOORD;
};

Texture2D g_texture : register(t0);
SamplerState g_sampler : register(s0);

struct DrawConstants
{
    float x;
    float y;
};
ConstantBuffer<DrawConstants> scale : register(b0, space0);

static const float3 colors[6] = {
    float3(1.0f,1.0f,1.0f), // 0 normal
    float3(1.0f,1.0f,1.0f), // 1 
    float3(0.337255f,0.478431f,0.890196f), // 2 // comment
    float3(1.0f,
0.188235f,
0.062745f), // 3 <header.h>, "string", 'char'
    float3(0.894118f,
0.145098f,
1.0f), // 4 #include, keyword
    float3(0.109804f,
0.929412f,
0.078431f) // 5 type
};

PSInput VSMain(float4 position : POSITION, uint color: COLOR, float4 uv : TEXCOORD)
{
    PSInput result;

    result.position = position;
    result.position.x = (result.position.x / scale.x/*1280*/) - 1.0f;
    result.position.y = (result.position.y / scale.y/*-720*/) + 1.0f;
    result.color = color;
    result.uv = uv;

    return result;
}

float4 PSMain(PSInput input) : SV_TARGET
{
    float4 tex = g_texture.Sample(g_sampler, input.uv);
    float3 color = colors[input.color];
    return float4(tex.r*color.r, tex.g*color.g, tex.b*color.b, tex.a);
}
